@@ -46,7 +46,7 @@ class DepositLineDetail(QuickbooksBaseObject):
     def __init__(self):
         super(DepositLineDetail, self).__init__()
         self.CheckNum = ""
-        self.TxnType = ""
+        self.TxnType = None
 
         self.Entity = None
         self.ClassRef = None
@@ -106,6 +106,10 @@ class Deposit(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMix
         "Line": DepositLine
     }
 
+    detail_dict = {
+        "DepositLineDetail": DepositLine
+    }
+
     qbo_object_name = "Deposit"
 
     def __init__(self):
