@@ -1,6 +1,9 @@
-from base import QuickbooksBaseObject, Ref, LinkedTxn, QuickbooksManagedObject, QuickbooksTransactionEntity
+from six import python_2_unicode_compatible
+from .base import QuickbooksBaseObject, Ref, LinkedTxn, QuickbooksManagedObject, QuickbooksTransactionEntity
+from .creditcardpayment import CreditCardPayment
 
 
+@python_2_unicode_compatible
 class PaymentLine(QuickbooksBaseObject):
     list_dict = {
         "LinkedTxn": LinkedTxn,
@@ -9,15 +12,13 @@ class PaymentLine(QuickbooksBaseObject):
     def __init__(self):
         super(PaymentLine, self).__init__()
         self.Amount = 0
-        self.LineNum = 0
-        self.Description = ""
-
         self.LinkedTxn = []
 
-    def __unicode__(self):
-        return "[{0}] {1} {2}".format(self.LineNum, self.Description, self.Amount)
+    def __str__(self):
+        return str(self.Amount)
 
 
+@python_2_unicode_compatible
 class Payment(QuickbooksManagedObject, QuickbooksTransactionEntity):
     """
     QBO definition: A Payment entity records a payment in QuickBooks. The payment can be applied for a particular
@@ -37,8 +38,12 @@ class Payment(QuickbooksManagedObject, QuickbooksTransactionEntity):
     """
 
     class_dict = {
+        "ARAccountRef": Ref,
         "CustomerRef": Ref,
         "PaymentMethodRef": Ref,
+        "DepositToAccountRef": Ref,
+        "CurrencyRef": Ref,
+        "CreditCardPayment": CreditCardPayment,
     }
 
     list_dict = {
@@ -49,13 +54,25 @@ class Payment(QuickbooksManagedObject, QuickbooksTransactionEntity):
 
     def __init__(self):
         super(Payment, self).__init__()
-        self.PaymentRefNum = 0
-        self.TotalAmt = 0
-        self.UnappliedAmt = 0
-        self.TxnDate = ""
+        self.PaymentRefNum = None
+        self.TotalAmt = None
+        self.UnappliedAmt = None  # Readonly
+        self.ExchangeRate = None
+        self.TxnDate = None
+        self.TxnSource = None
+        self.PrivateNote = None
+        self.TxnStatus = None
+
+        self.CreditCardPayment = None
+        self.ARAccountRef = None
         self.CustomerRef = None
+        self.CurrencyRef = None  # Readonly
         self.PaymentMethodRef = None
+        self.DepositToAccountRef = None
         self.Line = []
 
-    def __unicode__(self):
+        # These fields are for minor version 4
+        self.TransactionLocationType = None
+
+    def __str__(self):
         return str(self.TotalAmt)
